==> estateplat-common-1.2.4-20220419.060842-1005-sources.jar: cn/gtmap/estateplat/model/exchange/national/newStandard/QlfQlCfdjNew.java <==
package cn.gtmap.estateplat.model.exchange.national.newStandard;

import cn.gtmap.estateplat.model.exchange.national.AccessData;
import cn.gtmap.estateplat.utils.JaxbDateAdapter;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;

import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import java.io.Serializable;
import java.util.Date;

/**
 * 查封登记信息
 * Created by xhc on 2015/11/20.
 */

@XmlRootElement(name = "QLF_QL_CFDJ")
@Table(name = "QLF_QL_CFDJ")
public class QlfQlCfdjNew implements Serializable, AccessData {
    final static String ysdm = "6005080000";//要素代码
    private String bdcdyh;//不动产单元号
    private String ywh;//业务号
    private String cfjg;//查封机关
    private String cflx;//查封类型
    private String cfwj;//查封文件
    private String cfwh;//查封文号
    private Date cfqssj;//查封起始时间
    private Date cfjssj;//查封结束时间
    private String cffw;//查封范围
    private String qxdm;//区县代码
    private String djjg;//登记机构
    private String dbr;//登簿人
    private Date djsj;//登记时间
    private String jfywh;//解封业务号
    private String jfjg;//解封机关
    private String jfwj;//解封文件
    private String jfwh;//解封文号
    private String jfdbr;//解封登簿人
    private Date jfdjsj;//解封登记时间
    private String fj;//附记
    private String qszt;//权属状态
    /**  插入更新时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date updatetime;
    private String ysxkzmh;//预售许可证明号
    /**  插入创建时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date createtime;

    private Integer id;
    private String bdcqzh;
    private String bdcqzhjc;
    private String cxlxmc;
    private String qxdmmc;
    private String qsztmc;
    private String dzwbm;

    /**
     * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
     * @description 是否裁定
     */
    private String sfcd;

    private String ssywh;
    @XmlAttribute(name = "SSYWH")
    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }
    private String cfqx;
    @XmlAttribute(name = "CFQX")
    public String getCfqx() {
        return cfqx;
    }

    public void setCfqx(String cfqx) {
        this.cfqx = cfqx;
    }

    @XmlTransient
    public String getSfcd() {
        return sfcd;
    }

    public void setSfcd(String sfcd) {
        this.sfcd = sfcd;
    }

    @XmlTransient
    public Date getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }
    @XmlTransient
    public String getYsxkzmh() {
        return ysxkzmh;
    }
    public void setYsxkzmh(String ysxkzmh) {
        this.ysxkzmh = ysxkzmh;
    }
    @XmlTransient
    public Date getUpdatetime() {
        return updatetime;
    }

    public void setUpdatetime(Date updatetime) {
        this.updatetime = updatetime;
    }

    @XmlAttribute(name = "YSDM")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getYsdm() {
        return ysdm;
    }

    @XmlAttribute(name = "BDCDYH")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    @XmlAttribute(name = "YWH")
    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    @XmlAttribute(name = "CFJG")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getCfjg() {
        return cfjg;
    }

    public void setCfjg(String cfjg) {
        this.cfjg = cfjg;
    }

    @XmlAttribute(name = "CFLX")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getCflx() {
        return cflx;
    }

    public void setCflx(String cflx) {
        this.cflx = cflx;
    }

    @XmlAttribute(name = "CFWJ")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getCfwj() {
        return cfwj;
    }

    public void setCfwj(String cfwj) {
        this.cfwj = cfwj;
    }

    @XmlAttribute(name = "CFWH")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getCfwh() {
        return cfwh;
    }

    public void setCfwh(String cfwh) {
        this.cfwh = cfwh;
    }

    @XmlAttribute(name = "CFQSSJ")
    @XmlJavaTypeAdapter(JaxbDateAdapter.class)
    public Date getCfqssj() {
        return cfqssj;
    }

    public void setCfqssj(Date cfqssj) {
        this.cfqssj = cfqssj;
    }

    @XmlAttribute(name = "CFJSSJ")
    @XmlJavaTypeAdapter(JaxbDateAdapter.class)
    public Date getCfjssj() {
        return cfjssj;
    }

    public void setCfjssj(Date cfjssj) {
        this.cfjssj = cfjssj;
    }

    @XmlAttribute(name = "CFFW")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getCffw() {
        return cffw;
    }

    public void setCffw(String cffw) {
        this.cffw = cffw;
    }

    @XmlAttribute(name = "QXDM")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    @XmlAttribute(name = "DJJG")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    @XmlAttribute(name = "DBR")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    @XmlAttribute(name = "DJSJ")
    @XmlJavaTypeAdapter(JaxbDateAdapter.class)
    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    @XmlAttribute(name = "JFYWH")
    public String getJfywh() {
        return jfywh;
    }

    public void setJfywh(String jfywh) {
        this.jfywh = jfywh;
    }

    @XmlAttribute(name = "JFJG")
    public String getJfjg() {
        return jfjg;
    }

    public void setJfjg(String jfjg) {
        this.jfjg = jfjg;
    }

    @XmlAttribute(name = "JFWJ")
    public String getJfwj() {
        return jfwj;
    }

    public void setJfwj(String jfwj) {
        this.jfwj = jfwj;
    }

    @XmlAttribute(name = "JFWH")
    public String getJfwh() {
        return jfwh;
    }

    public void setJfwh(String jfwh) {
        this.jfwh = jfwh;
    }

    @XmlAttribute(name = "JFDBR")
    public String getJfdbr() {
        return jfdbr;
    }

    public void setJfdbr(String jfdbr) {
        this.jfdbr = jfdbr;
    }

    @XmlAttribute(name = "JFDJSJ")
    @XmlJavaTypeAdapter(JaxbDateAdapter.class)
    public Date getJfdjsj() {
        return jfdjsj;
    }

    public void setJfdjsj(Date jfdjsj) {
        this.jfdjsj = jfdjsj;
    }

    @XmlAttribute(name = "FJ")
    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    @XmlAttribute(name = "QSZT")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }
    @XmlTransient
    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }
    @XmlTransient
    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }
    @XmlTransient
    public String getBdcqzhjc() {
        return bdcqzhjc;
    }

    public void setBdcqzhjc(String bdcqzhjc) {
        this.bdcqzhjc = bdcqzhjc;
    }
    @XmlTransient
    public String getCxlxmc() {
        return cxlxmc;
    }

    public void setCxlxmc(String cxlxmc) {
        this.cxlxmc = cxlxmc;
    }
    @XmlTransient
    public String getQxdmmc() {
        return qxdmmc;
    }

    public void setQxdmmc(String qxdmmc) {
        this.qxdmmc = qxdmmc;
    }
    @XmlTransient
    public String getQsztmc() {
        return qsztmc;
    }

    public void setQsztmc(String qsztmc) {
        this.qsztmc = qsztmc;
    }
    @XmlTransient
    public String getDzwbm() {
        return dzwbm;
    }

    public void setDzwbm(String dzwbm) {
        this.dzwbm = dzwbm;
    }
}

==> estateplat-common-1.2.4-20220622.062135-1050-sources.jar: cn/gtmap/estateplat/model/exchange/national/newStandard/QlfQlCfdjNew.java <==
package cn.gtmap.estateplat.model.exchange.national.newStandard;

import cn.gtmap.estateplat.model.exchange.national.AccessData;
import cn.gtmap.estateplat.utils.JaxbDateAdapter;
import cn.gtmap.estateplat.utils.JaxbNotNullDateAdapter;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;

import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import java.io.Serializable;
import java.util.Date;

/**
 * 查封登记信息
 * Created by xhc on 2015/11/20.
 */

@XmlRootElement(name = "QLF_QL_CFDJ")
@Table(name = "QLF_QL_CFDJ")
public class QlfQlCfdjNew implements Serializable, AccessData {
    final static String ysdm = "6005080000";//要素代码
    private String bdcdyh;//不动产单元号
    private String ywh;//业务号
    private String cfjg;//查封机关
    private String cflx;//查封类型
    private String cfwj;//查封文件
    private String cfwh;//查封文号
    private Date cfqssj;//查封起始时间
    private Date cfjssj;//查封结束时间
    private String cffw;//查封范围
    private String qxdm;//区县代码
    private String djjg;//登记机构
    private String dbr;//登簿人
    private Date djsj;//登记时间
    private String jfywh;//解封业务号
    private String jfjg;//解封机关
    private String jfwj;//解封文件
    private String jfwh;//解封文号
    private String jfdbr;//解封登簿人
    private Date jfdjsj;//解封登记时间
    private String fj;//附记
    private String qszt;//权属状态
    /**  插入更新时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date updatetime;
    private String ysxkzmh;//预售许可证明号
    /**  插入创建时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date createtime;

    private Integer id;
    private String bdcqzh;
    private String bdcqzhjc;
    private String cxlxmc;
    private String qxdmmc;
    private String qsztmc;
    private String dzwbm;

    /**
     * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
     * @description 是否裁定
     */
    private String sfcd;

    private String ssywh;
    @XmlAttribute(name = "SSYWH")
    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }
    private String cfqx;
    @XmlAttribute(name = "CFQX")
    public String getCfqx() {
        return cfqx;
    }

    public void setCfqx(String cfqx) {
        this.cfqx = cfqx;
    }

    @XmlTransient
    public String getSfcd() {
        return sfcd;
    }

    public void setSfcd(String sfcd) {
        this.sfcd = sfcd;
    }

    @XmlTransient
    public Date getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }
    @XmlTransient
    public String getYsxkzmh() {
        return ysxkzmh;
    }
    public void setYsxkzmh(String ysxkzmh) {
        this.ysxkzmh = ysxkzmh;
    }
    @XmlTransient
    public Date getUpdatetime() {
        return updatetime;
    }

    public void setUpdatetime(Date updatetime) {
        this.updatetime = updatetime;
    }

    @XmlAttribute(name = "YSDM")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getYsdm() {
        return ysdm;
    }

    @XmlAttribute(name = "BDCDYH")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    @XmlAttribute(name = "YWH")
    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    @XmlAttribute(name = "CFJG")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getCfjg() {
        return cfjg;
    }

    public void setCfjg(String cfjg) {
        this.cfjg = cfjg;
    }

    @XmlAttribute(name = "CFLX")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getCflx() {
        return cflx;
    }

    public void setCflx(String cflx) {
        this.cflx = cflx;
    }

    @XmlAttribute(name = "CFWJ")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getCfwj() {
        return cfwj;
    }

    public void setCfwj(String cfwj) {
        this.cfwj = cfwj;
    }

    @XmlAttribute(name = "CFWH")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getCfwh() {
        return cfwh;
    }

    public void setCfwh(String cfwh) {
        this.cfwh = cfwh;
    }

    @XmlAttribute(name = "CFQSSJ")
    @XmlJavaTypeAdapter(JaxbNotNullDateAdapter.class)
    public Date getCfqssj() {
        return cfqssj;
    }

    public void setCfqssj(Date cfqssj) {
        this.cfqssj = cfqssj;
    }

    @XmlAttribute(name = "CFJSSJ")
    @XmlJavaTypeAdapter(JaxbNotNullDateAdapter.class)
    public Date getCfjssj() {
        return cfjssj;
    }

    public void setCfjssj(Date cfjssj) {
        this.cfjssj = cfjssj;
    }

    @XmlAttribute(name = "CFFW")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getCffw() {
        return cffw;
    }

    public void setCffw(String cffw) {
        this.cffw = cffw;
    }

    @XmlAttribute(name = "QXDM")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    @XmlAttribute(name = "DJJG")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    @XmlAttribute(name = "DBR")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    @XmlAttribute(name = "DJSJ")
    @XmlJavaTypeAdapter(JaxbNotNullDateAdapter.class)
    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    @XmlAttribute(name = "JFYWH")
    public String getJfywh() {
        return jfywh;
    }

    public void setJfywh(String jfywh) {
        this.jfywh = jfywh;
    }

    @XmlAttribute(name = "JFJG")
    public String getJfjg() {
        return jfjg;
    }

    public void setJfjg(String jfjg) {
        this.jfjg = jfjg;
    }

    @XmlAttribute(name = "JFWJ")
    public String getJfwj() {
        return jfwj;
    }

    public void setJfwj(String jfwj) {
        this.jfwj = jfwj;
    }

    @XmlAttribute(name = "JFWH")
    public String getJfwh() {
        return jfwh;
    }

    public void setJfwh(String jfwh) {
        this.jfwh = jfwh;
    }

    @XmlAttribute(name = "JFDBR")
    public String getJfdbr() {
        return jfdbr;
    }

    public void setJfdbr(String jfdbr) {
        this.jfdbr = jfdbr;
    }

    @XmlAttribute(name = "JFDJSJ")
    @XmlJavaTypeAdapter(JaxbNotNullDateAdapter.class)
    public Date getJfdjsj() {
        return jfdjsj;
    }

    public void setJfdjsj(Date jfdjsj) {
        this.jfdjsj = jfdjsj;
    }

    @XmlAttribute(name = "FJ")
    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    @XmlAttribute(name = "QSZT")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }
    @XmlTransient
    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }
    @XmlTransient
    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }
    @XmlTransient
    public String getBdcqzhjc() {
        return bdcqzhjc;
    }

    public void setBdcqzhjc(String bdcqzhjc) {
        this.bdcqzhjc = bdcqzhjc;
    }
    @XmlTransient
    public String getCxlxmc() {
        return cxlxmc;
    }

    public void setCxlxmc(String cxlxmc) {
        this.cxlxmc = cxlxmc;
    }
    @XmlTransient
    public String getQxdmmc() {
        return qxdmmc;
    }

    public void setQxdmmc(String qxdmmc) {
        this.qxdmmc = qxdmmc;
    }
    @XmlTransient
    public String getQsztmc() {
        return qsztmc;
    }

    public void setQsztmc(String qsztmc) {
        this.qsztmc = qsztmc;
    }
    @XmlTransient
    public String getDzwbm() {
        return dzwbm;
    }

    public void setDzwbm(String dzwbm) {
        this.dzwbm = dzwbm;
    }
}
